[−][src]Crate heim_common
This crate shares common functionality across the heim sub-crates.
Do NOT use it directly.
Modules
| prelude | Prelude intended to be used across |
| units | Measurement units used in API. |
Enums
| Error | Any error which may happen during the data fetch. |
Type Definitions
| Pid | Process identifier type. |
| Result | Type alias for types returned by |