[−][src]Enum heim_common::prelude::future::ExecuteErrorKind
Kinds of errors that can be returned from the Execute::spawn function.
Executors which may not always be able to accept a future may return one of these errors, indicating why it was unable to spawn a future.
Variants
ShutdownThis executor has shut down and will no longer accept new futures to spawn.
NoCapacityThis executor has no more capacity to run more futures. Other futures need to finish before this executor can accept another.