[−][src]Struct heim_common::units::information::byte
The byte is a unit of information consisting of 8 bits.
Although the bit is the base unit of information uom treats it as a derived unit. The
byte is treated as the base unit in order to provide more accurate conversion factors
for byte derived units which are more commonly used than bits.